summaryrefslogtreecommitdiff
path: root/eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java
diff options
context:
space:
mode:
Diffstat (limited to 'eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java')
-rw-r--r--eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java b/eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java
index dc7e9338..14e6a78a 100644
--- a/eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java
+++ b/eaaf_modules/eaaf_module_pvp2_core/src/main/java/at/gv/egiz/eaaf/modules/pvp2/impl/utils/Saml2Utils.java
@@ -132,7 +132,7 @@ public class Saml2Utils {
@Nonnull EaafX509Credential signingCredential, boolean injectCertificate) throws SamlSigningException {
try {
- final String usedSigAlg = getSignatureAlgorithm(signingCredential,
+ final String usedSigAlg = getKeyOperationAlgorithmFromCredential(signingCredential,
PvpConstants.DEFAULT_SIGNING_METHODE_RSA,
PvpConstants.DEFAULT_SIGNING_METHODE_EC);
@@ -218,15 +218,15 @@ public class Saml2Utils {
/**
* Select signature algorithm for a given credential.
*
* @param credentials {@link X509Credential} that will be used for signing
* @param rsaSigAlgorithm RSA based signing algorithm that should be used in
* case of RSA credential
- * @param ecSigAlgorithm EC based signing algorithm that should be used in case
+ * @param ecSigAlgorithm EC based algorithm that should be used in case
* of RSA credential
- * @return either the rsaSigAlgorithm or the ecSigAlgorithm
+ * @return either the RSA based algorithm or the EC based algorithm
* @throws SamlSigningException In case of an unsupported credential
*/
- public static String getSignatureAlgorithm(X509Credential credentials,
+ public static String getKeyOperationAlgorithmFromCredential(X509Credential credentials,
String rsaSigAlgorithm, String ecSigAlgorithm) throws SamlSigningException {
final PrivateKey privatekey = credentials.getPrivateKey();
if (privatekey instanceof RSAPrivateKey) {
@@ -218,15 +218,15 @@ public class Saml2Utils {
* Select signature algorithm for a given credential.
*
- * @param credentials {@link X509Credential} that will be used for signing
- * @param rsaSigAlgorithm RSA based signing algorithm that should be used in
+ * @param credentials {@link X509Credential} that will be used for key operations
+ * @param rsaSigAlgorithm RSA based algorithm that should be used in
* case of RSA credential